@@ -13,6 +13,21 @@
         <source>Version</source>
         <translation>Version</translation>
     </message>
+    <message>
+        <location filename="../../src/dialogs/aboutdialog.cpp" line="60"/>
+        <source>A customizable launcher for &lt;ParentName&gt; using Qt.</source>
+        <translation>Une interface élémentaire pour &lt;ParentName&gt;.</translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/aboutdialog.cpp" line="64"/>
+        <source>&lt;ParentName&gt; website</source>
+        <translation>Site web de &lt;ParentName&gt;</translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/aboutdialog.cpp" line="66"/>
+        <source>GitHub repository</source>
+        <translation>Dépôt GitHub</translation>
+    </message>
 </context>
 <context>
     <name>ConfigEditor</name>
@@ -22,10 +37,169 @@
         <translation>Éditeur de configuration &lt;ParentName&gt;</translation>
     </message>
     <message>
-        <location filename="../../src/dialogs/configeditor.cpp" line="73"/>
+        <location filename="../../src/dialogs/configeditor.cpp" line="72"/>
+        <source>Key Codes Reference</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/configeditor.cpp" line="75"/>
+        <source>Mupen64Plus Documentation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/configeditor.cpp" line="83"/>
         <source>Save</source>
         <translation>Sauvegarder</translation>
     </message>
+    <message>
+        <location filename="../../src/dialogs/configeditor.cpp" line="84"/>
+        <source>Cancel</source>
+        <translation>Annuler</translation>
+    </message>
+</context>
+<context>
+    <name>ControlInfo</name>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="45"/>
+        <source>Mupen64Plus Default Controls</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="51"/>
+        <source>These are the default controls for Mupen64Plus. </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="52"/>
+        <source>They can be modified using Settings-&gt;Edit mupen64plus.cfg...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="54"/>
+        <source>For more information see the &lt;link&gt;Mupen64Plus Documentation&lt;linkend&gt;. </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="57"/>
+        <source>For setting up a gamepad controller see &lt;link&gt;this page&lt;linkend&gt;. </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="60"/>
+        <source>Note that Mupen64Plus output can be viewed with Emulation-&gt;View Log.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="92"/>
+        <source>N64 Input</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="92"/>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="142"/>
+        <source>Key</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="122"/>
+        <source>Quit the emulator</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="123"/>
+        <source>Select virtual &apos;slot&apos; for save/load state commands</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="124"/>
+        <source>Save emulator state</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="125"/>
+        <source>Load emulator state</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="126"/>
+        <source>Reset emulator</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="127"/>
+        <source>Slow down emulator by 5%</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="128"/>
+        <source>Speed up emulator by 5%</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="129"/>
+        <source>Take screenshot</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="130"/>
+        <source>Toggle between windowed and fullscreen</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="131"/>
+        <source>Pause on/off</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="132"/>
+        <source>Mute/unmute sound</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="133"/>
+        <source>Press &quot;Game Shark&quot; button (only if cheats are enabled)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="134"/>
+        <source>Single frame advance while paused</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="135"/>
+        <source>Fast forward (playback at 250% normal speed while pressed)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="136"/>
+        <source>Decrease volume</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="137"/>
+        <source>Increase volume</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="142"/>
+        <source>Action</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="160"/>
+        <source>Close</source>
+        <translation>Fermer</translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="165"/>
+        <source>Controller Input</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/controlinfodialog.cpp" line="166"/>
+        <source>Hotkeys</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DownloadDialog</name>
@@ -59,39 +233,54 @@
         <source>Search</source>
         <translation>Chercher</translation>
     </message>
+    <message>
+        <location filename="../../src/dialogs/downloaddialog.cpp" line="67"/>
+        <source>Cancel</source>
+        <translation>Annuler</translation>
+    </message>
 </context>
 <context>
     <name>EmulatorHandler</name>
     <message>
-        <location filename="../../src/emulation/emulatorhandler.cpp" line="62"/>
-        <location filename="../../src/emulation/emulatorhandler.cpp" line="190"/>
-        <location filename="../../src/emulation/emulatorhandler.cpp" line="197"/>
-        <location filename="../../src/emulation/emulatorhandler.cpp" line="207"/>
+        <location filename="../../src/emulation/emulatorhandler.cpp" line="56"/>
+        <location filename="../../src/emulation/emulatorhandler.cpp" line="189"/>
+        <location filename="../../src/emulation/emulatorhandler.cpp" line="196"/>
+        <location filename="../../src/emulation/emulatorhandler.cpp" line="206"/>
         <source>Warning</source>
         <translation>Attention</translation>
     </message>
     <message>
-        <location filename="../../src/emulation/emulatorhandler.cpp" line="63"/>
+        <location filename="../../src/emulation/emulatorhandler.cpp" line="57"/>
         <source>&lt;ParentName&gt; quit unexpectedly. Check the log for more information.</source>
         <translation>&lt;ParentName&gt; a quitté de manière inattendue. Consultez les journaux pour plus d&apos;informations.</translation>
     </message>
     <message>
-        <location filename="../../src/emulation/emulatorhandler.cpp" line="67"/>
-        <source>View Log...</source>
-        <translation>Consulter les journaux...</translation>
+        <location filename="../../src/emulation/emulatorhandler.cpp" line="61"/>
+        <source>View Log</source>
+        <translation>Consulter les journaux</translation>
     </message>
     <message>
-        <location filename="../../src/emulation/emulatorhandler.cpp" line="191"/>
+        <location filename="../../src/emulation/emulatorhandler.cpp" line="126"/>
+        <source>There was no output. If you were expecting Mupen64Plus to run, try copying</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/emulation/emulatorhandler.cpp" line="127"/>
+        <source>the above command into a command prompt to see if you get an error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/emulation/emulatorhandler.cpp" line="190"/>
         <source>&lt;ParentName&gt; executable not found.</source>
         <translation>Executable &lt;ParentName&gt; non trouvé.</translation>
     </message>
     <message>
-        <location filename="../../src/emulation/emulatorhandler.cpp" line="207"/>
+        <location filename="../../src/emulation/emulatorhandler.cpp" line="206"/>
         <source>Not a valid ROM File.</source>
         <translation>Fichier ROM invalide.</translation>
     </message>
     <message>
-        <location filename="../../src/emulation/emulatorhandler.cpp" line="197"/>
+        <location filename="../../src/emulation/emulatorhandler.cpp" line="196"/>
         <source>ROM file not found.</source>
         <translation>Fichier ROM manquant.</translation>
     </message>
@@ -105,7 +294,7 @@
     </message>
     <message>
         <location filename="../../src/dialogs/gamesettingsdialog.ui" line="26"/>
-        <source>Game settings for: </source>
+        <source>Game settings for:</source>
         <translation>Paramètres du jeu pour :</translation>
     </message>
     <message>
@@ -167,7 +356,17 @@
         <translation>Naviguer...</translation>
     </message>
     <message>
-        <location filename="../../src/dialogs/gamesettingsdialog.cpp" line="107"/>
+        <location filename="../../src/dialogs/gamesettingsdialog.cpp" line="92"/>
+        <source>OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/gamesettingsdialog.cpp" line="93"/>
+        <source>Cancel</source>
+        <translation>Annuler</translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/gamesettingsdialog.cpp" line="110"/>
         <source>Config Directory</source>
         <translation>Dossier de configuration</translation>
     </message>
@@ -175,15 +374,38 @@
 <context>
     <name>GridView</name>
     <message>
-        <location filename="../../src/views/gridview.cpp" line="144"/>
+        <location filename="../../src/views/gridview.cpp" line="145"/>
         <source>No Cart</source>
         <translation>Pas de cartouche</translation>
     </message>
 </context>
+<context>
+    <name>KeyCodes</name>
+    <message>
+        <location filename="../../src/dialogs/keycodesdialog.cpp" line="43"/>
+        <source>SDL Key Codes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/keycodesdialog.cpp" line="189"/>
+        <source>Key</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/keycodesdialog.cpp" line="189"/>
+        <source>SDL Code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/keycodesdialog.cpp" line="202"/>
+        <source>Close</source>
+        <translation>Fermer</translation>
+    </message>
+</context>
 <context>
     <name>ListView</name>
     <message>
-        <location filename="../../src/views/listview.cpp" line="158"/>
+        <location filename="../../src/views/listview.cpp" line="159"/>
         <source>No Cart</source>
         <translation>Pas de cartouche</translation>
     </message>
@@ -191,12 +413,12 @@
 <context>
     <name>LogDialog</name>
     <message>
-        <location filename="../../src/dialogs/logdialog.cpp" line="47"/>
+        <location filename="../../src/dialogs/logdialog.cpp" line="44"/>
         <source>&lt;ParentName&gt; Log</source>
         <translation>Journaux &lt;ParentName&gt;</translation>
     </message>
     <message>
-        <location filename="../../src/dialogs/logdialog.cpp" line="67"/>
+        <location filename="../../src/dialogs/logdialog.cpp" line="59"/>
         <source>Close</source>
         <translation>Fermer</translation>
     </message>
@@ -204,305 +426,334 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="250"/>
+        <location filename="../../src/mainwindow.cpp" line="254"/>
         <source>&amp;File</source>
         <translation>&amp;Fichier</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="251"/>
+        <location filename="../../src/mainwindow.cpp" line="255"/>
         <source>&amp;Open ROM...</source>
         <translation>&amp;Ouvrir une ROM...</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="253"/>
+        <location filename="../../src/mainwindow.cpp" line="257"/>
         <source>&amp;Refresh List</source>
         <translation>&amp;Recharger la liste</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="254"/>
-        <location filename="../../src/mainwindow.cpp" line="885"/>
+        <location filename="../../src/mainwindow.cpp" line="258"/>
+        <location filename="../../src/mainwindow.cpp" line="912"/>
         <source>&amp;Download/Update Info...</source>
         <translation>&amp;Télécharger/Mettre à jour les infos...</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="255"/>
-        <location filename="../../src/mainwindow.cpp" line="886"/>
+        <location filename="../../src/mainwindow.cpp" line="259"/>
+        <location filename="../../src/mainwindow.cpp" line="913"/>
         <source>D&amp;elete Current Info...</source>
         <translation>&amp;Effacer les infos actuelles...</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="259"/>
+        <location filename="../../src/mainwindow.cpp" line="263"/>
         <source>&amp;Quit</source>
         <translation>&amp;Quitter</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="278"/>
+        <location filename="../../src/mainwindow.cpp" line="282"/>
         <source>&amp;Emulation</source>
         <translation>&amp;Émulation</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="279"/>
-        <location filename="../../src/mainwindow.cpp" line="875"/>
+        <location filename="../../src/mainwindow.cpp" line="283"/>
+        <location filename="../../src/mainwindow.cpp" line="902"/>
         <source>&amp;Start</source>
         <translation>&amp;Démarrer</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="280"/>
+        <location filename="../../src/mainwindow.cpp" line="284"/>
         <source>St&amp;op</source>
         <translation>&amp;Arrêter</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="282"/>
-        <source>View Log...</source>
-        <translation>Consulter les journaux...</translation>
-    </message>
-    <message>
-        <location filename="../../src/mainwindow.cpp" line="298"/>
+        <location filename="../../src/mainwindow.cpp" line="302"/>
         <source>&amp;Settings</source>
         <translation>&amp;Paramètres</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="299"/>
+        <location filename="../../src/mainwindow.cpp" line="303"/>
         <source>Edit mupen64plus.cfg...</source>
         <translation>Éditer mupen64plus.cfg...</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="301"/>
-        <location filename="../../src/mainwindow.cpp" line="878"/>
+        <location filename="../../src/mainwindow.cpp" line="305"/>
+        <location filename="../../src/mainwindow.cpp" line="905"/>
         <source>Configure &amp;Game...</source>
         <translation>Configurer le &amp;jeu...</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="305"/>
+        <location filename="../../src/mainwindow.cpp" line="309"/>
         <source>&amp;Configure...</source>
         <translation>&amp;Configurer...</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="713"/>
+        <location filename="../../src/mainwindow.cpp" line="738"/>
         <source>There is no log. Either &lt;ParentName&gt; has not yet run or there was no output from the last run.</source>
         <translation>Il n&apos;y a pas de journaux. Soit &lt;ParentName&gt; n’a pas encore été lancé, soit il n’y a pas de données concernant le dernier démarrage.</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="319"/>
+        <location filename="../../src/mainwindow.cpp" line="323"/>
         <source>&amp;Layout</source>
         <translation>&amp;Disposition</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="318"/>
+        <location filename="../../src/mainwindow.cpp" line="286"/>
+        <source>View Log</source>
+        <translation>Consulter les journaux</translation>
+    </message>
+    <message>
+        <location filename="../../src/mainwindow.cpp" line="322"/>
         <source>&amp;View</source>
         <translation>&amp;Affichage</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="323"/>
+        <location filename="../../src/mainwindow.cpp" line="327"/>
         <source>None</source>
         <translation>Aucune</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="324"/>
+        <location filename="../../src/mainwindow.cpp" line="328"/>
         <source>Table View</source>
         <translation>Vue en tableau</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="325"/>
+        <location filename="../../src/mainwindow.cpp" line="329"/>
         <source>Grid View</source>
         <translation>Vue en vignettes</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="326"/>
+        <location filename="../../src/mainwindow.cpp" line="330"/>
         <source>List View</source>
         <translation>Vue en liste</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="349"/>
-        <location filename="../../src/mainwindow.cpp" line="353"/>
+        <location filename="../../src/mainwindow.cpp" line="357"/>
         <source>&amp;Full-screen</source>
         <translation>Pl&amp;ein-Écran</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="367"/>
+        <location filename="../../src/mainwindow.cpp" line="373"/>
         <source>&amp;Help</source>
         <translation>&amp;Aide</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="368"/>
+        <location filename="../../src/mainwindow.cpp" line="374"/>
+        <source>Documentation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/mainwindow.cpp" line="375"/>
+        <source>Mupen64Plus Docs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/mainwindow.cpp" line="377"/>
+        <source>Default Controls</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/mainwindow.cpp" line="379"/>
         <source>&amp;About</source>
         <translation>À &amp;propos</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="690"/>
+        <location filename="../../src/mainwindow.cpp" line="461"/>
+        <source>Add a directory containing ROMs under </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/mainwindow.cpp" line="462"/>
+        <source>Settings-&gt;Configure-&gt;Paths to use this view.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/mainwindow.cpp" line="715"/>
         <source>Not Found</source>
         <translation>Non trouvé</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="690"/>
+        <location filename="../../src/mainwindow.cpp" line="715"/>
         <source>Editor requires config directory to be </source>
         <translation>L&apos;éditeur nécessite que le dossier de configuration soit </translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="691"/>
+        <location filename="../../src/mainwindow.cpp" line="716"/>
         <source>set to a directory with mupen64plus.cfg.</source>
         <translation>un dossier contenant mupen64plus.cfg.</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="692"/>
+        <location filename="../../src/mainwindow.cpp" line="717"/>
         <source>See here for the default config location:</source>
         <translation>Voir ici pour la configuration par défaut:</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="712"/>
+        <location filename="../../src/mainwindow.cpp" line="737"/>
         <source>No Output</source>
         <translation>Pas de sortie</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="765"/>
+        <location filename="../../src/mainwindow.cpp" line="796"/>
         <source>All Files</source>
         <translation>Tous les fichiers</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="775"/>
+        <location filename="../../src/mainwindow.cpp" line="802"/>
         <source>Open ROM File</source>
         <translation>Ouvrir un fichier ROM</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="793"/>
+        <location filename="../../src/mainwindow.cpp" line="820"/>
         <source>No ROMs</source>
         <translation>Aucune ROM</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="793"/>
+        <location filename="../../src/mainwindow.cpp" line="820"/>
         <source>No ROMs found in ZIP file.</source>
         <translation>Aucune ROM trouvée dans le fichier ZIP.</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="808"/>
+        <location filename="../../src/mainwindow.cpp" line="835"/>
         <source>Select ROM</source>
         <translation>Choisir une ROM</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="825"/>
+        <location filename="../../src/mainwindow.cpp" line="852"/>
         <source>Launch</source>
         <translation>Lancer</translation>
     </message>
+    <message>
+        <location filename="../../src/mainwindow.cpp" line="853"/>
+        <source>Cancel</source>
+        <translation>Annuler</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../../src/common.cpp" line="338"/>
+        <location filename="../../src/common.cpp" line="328"/>
         <source>GoodName</source>
         <translation>Nom Good</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="339"/>
+        <location filename="../../src/common.cpp" line="329"/>
         <source>Filename</source>
         <translation>Nom du fichier</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="340"/>
+        <location filename="../../src/common.cpp" line="330"/>
         <source>Filename (extension)</source>
         <translation>Nom du fichier (extension)</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="341"/>
+        <location filename="../../src/common.cpp" line="331"/>
         <source>Zip File</source>
         <translation>Fichier Zip</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="342"/>
+        <location filename="../../src/common.cpp" line="332"/>
         <source>Internal Name</source>
         <translation>Nom interne</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="343"/>
+        <location filename="../../src/common.cpp" line="333"/>
         <source>Size</source>
         <translation>Taille</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="344"/>
+        <location filename="../../src/common.cpp" line="334"/>
         <source>MD5</source>
         <translation>MD5</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="345"/>
+        <location filename="../../src/common.cpp" line="335"/>
         <source>CRC1</source>
         <translation>CRC1</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="346"/>
+        <location filename="../../src/common.cpp" line="336"/>
         <source>CRC2</source>
         <translation>CRC2</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="347"/>
+        <location filename="../../src/common.cpp" line="337"/>
         <source>Players</source>
         <translation>Joueurs</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="348"/>
+        <location filename="../../src/common.cpp" line="338"/>
         <source>Rumble</source>
         <translation>Rumble</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="349"/>
+        <location filename="../../src/common.cpp" line="339"/>
         <source>Save Type</source>
         <translation>Type de sauvegarde</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="350"/>
+        <location filename="../../src/common.cpp" line="340"/>
         <source>Game Title</source>
         <translation>Titre du jeu</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="351"/>
+        <location filename="../../src/common.cpp" line="341"/>
         <source>Release Date</source>
         <translation>Date de sortie</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="352"/>
+        <location filename="../../src/common.cpp" line="342"/>
         <source>Overview</source>
         <translation>Aperçu</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="353"/>
+        <location filename="../../src/common.cpp" line="343"/>
         <source>ESRB</source>
         <translation>ESRB</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="354"/>
+        <location filename="../../src/common.cpp" line="344"/>
         <source>Genre</source>
         <translation>Genre</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="355"/>
+        <location filename="../../src/common.cpp" line="345"/>
         <source>Publisher</source>
         <translation>Éditeur</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="356"/>
+        <location filename="../../src/common.cpp" line="346"/>
         <source>Developer</source>
         <translation>Développeur</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="357"/>
+        <location filename="../../src/common.cpp" line="347"/>
         <source>Rating</source>
         <translation>Certification</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="358"/>
+        <location filename="../../src/common.cpp" line="348"/>
         <source>Game Cover</source>
         <translation>Jaquette</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="359"/>
+        <location filename="../../src/common.cpp" line="349"/>
         <source>Unknown ROM</source>
         <translation>ROM inconnue</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="360"/>
+        <location filename="../../src/common.cpp" line="350"/>
         <source>Requires catalog file</source>
         <translation>Fichier catalogue demandé</translation>
     </message>
     <message>
-        <location filename="../../src/common.cpp" line="361"/>
+        <location filename="../../src/common.cpp" line="351"/>
         <source>Not found</source>
         <translation>Non trouvé</translation>
     </message>
@@ -533,21 +784,6 @@
         <source>Download Complete!</source>
         <translation>Téléchargement terminé !</translation>
     </message>
-    <message>
-        <location filename="../../src/global.h" line="44"/>
-        <source>A customizable launcher for &lt;ParentName&gt; using Qt.</source>
-        <translation>Une interface élémentaire pour &lt;ParentName&gt;.</translation>
-    </message>
-    <message>
-        <location filename="../../src/global.h" line="47"/>
-        <source>&lt;ParentName&gt; website</source>
-        <translation>Site web de &lt;ParentName&gt;</translation>
-    </message>
-    <message>
-        <location filename="../../src/global.h" line="50"/>
-        <source>GitHub repository</source>
-        <translation>Dépôt GitHub</translation>
-    </message>
 </context>
 <context>
     <name>RomCollection</name>
@@ -906,6 +1142,11 @@
         <source>&lt;b&gt;Note:&lt;/b&gt; Language changes will not take place until application restart.</source>
         <translation>&lt;b&gt;Remarque :&lt;/b&gt; Le changement de langue ne prendra effet qu&apos;après le redémarrage du programme.</translation>
     </message>
+    <message>
+        <location filename="../../src/dialogs/settingsdialog.cpp" line="86"/>
+        <source>default</source>
+        <translation>Défaut</translation>
+    </message>
     <message>
         <location filename="../../src/dialogs/settingsdialog.cpp" line="179"/>
         <source>Extra Small</source>
@@ -1019,32 +1260,42 @@
         <translation>Sombre</translation>
     </message>
     <message>
-        <location filename="../../src/dialogs/settingsdialog.cpp" line="420"/>
+        <location filename="../../src/dialogs/settingsdialog.cpp" line="394"/>
+        <source>OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/settingsdialog.cpp" line="395"/>
+        <source>Cancel</source>
+        <translation>Annuler</translation>
+    </message>
+    <message>
+        <location filename="../../src/dialogs/settingsdialog.cpp" line="424"/>
         <source>ROM Directory</source>
         <translation>Dossiers des ROMS</translation>
     </message>
     <message>
-        <location filename="../../src/dialogs/settingsdialog.cpp" line="444"/>
+        <location filename="../../src/dialogs/settingsdialog.cpp" line="448"/>
         <source>&lt;ParentName&gt; Executable</source>
         <translation>Fichier exécutable &lt;ParentName&gt;</translation>
     </message>
     <message>
-        <location filename="../../src/dialogs/settingsdialog.cpp" line="462"/>
+        <location filename="../../src/dialogs/settingsdialog.cpp" line="466"/>
         <source>Plugin Directory</source>
         <translation>Dossier des plugins</translation>
     </message>
     <message>
-        <location filename="../../src/dialogs/settingsdialog.cpp" line="471"/>
+        <location filename="../../src/dialogs/settingsdialog.cpp" line="475"/>
         <source>Data Directory</source>
         <translation>Dossier des données</translation>
     </message>
     <message>
-        <location filename="../../src/dialogs/settingsdialog.cpp" line="479"/>
+        <location filename="../../src/dialogs/settingsdialog.cpp" line="483"/>
         <source>Config Directory</source>
         <translation>Dossier de configuration</translation>
     </message>
     <message>
-        <location filename="../../src/dialogs/settingsdialog.cpp" line="436"/>
+        <location filename="../../src/dialogs/settingsdialog.cpp" line="440"/>
         <source>Background Image</source>
         <translation>Image d&apos;arrière-plan</translation>
     </message>
@@ -1052,8 +1303,8 @@
 <context>
     <name>TableView</name>
     <message>
-        <location filename="../../src/views/tableview.cpp" line="76"/>
-        <location filename="../../src/views/tableview.cpp" line="79"/>
+        <location filename="../../src/views/tableview.cpp" line="78"/>
+        <location filename="../../src/views/tableview.cpp" line="81"/>
         <source>No Cart</source>
         <translation>Pas de cartouche</translation>
     </message>
