@@ -505,8 +505,8 @@ void SettingsDialog::editSettings()
     SETTINGS.setValue("Paths/config", ui->configPath->text());
 
     QStringList romDirectories;
-    foreach (QListWidgetItem *item, ui->romList->findItems("*", Qt::MatchWildcard))
-        romDirectories << item->text();
+    for (int i = 0; i < ui->romList->count(); i++)
+        romDirectories << ui->romList->item(i)->text();
 
     SETTINGS.setValue("Paths/roms", romDirectories.join("|"));
 
