@@ -68,6 +68,7 @@ protected:
 
 private:
     void autoloadSettings();
+    void checkConfigLocation();
     void createMenu();
     void createRomView();
     void openZipDialog(QStringList zippedFiles);
@@ -80,11 +81,14 @@ private:
     QAction *aboutAction;
     QAction *configureAction;
     QAction *configureGameAction;
+    QAction *controlInfoAction;
     QAction *deleteAction;
+    QAction *documentationAction;
     QAction *downloadAction;
     QAction *editorAction;
     QAction *fullScreenAction;
     QAction *logAction;
+    QAction *mupenDocsAction;
     QAction *openAction;
     QAction *quitAction;
     QAction *refreshAction;
@@ -133,6 +137,7 @@ private slots:
     void launchRomFromWidget(QWidget *current);
     void launchRomFromZip();
     void openAbout();
+    void openDefaultControls();
     void openDeleteDialog();
     void openDownloader();
     void openEditor();
@@ -146,7 +151,8 @@ private slots:
     void toggleMenus(bool active);
     void updateFullScreenMode();
     void updateLayoutSetting();
-
+    void openDocumentation();
+    void openMupenDocs();
 };
 
 #endif // MAINWINDOW_H
